@@ -67,6 +67,8 @@ class DiscoverObject : public QObject
         void openMode(const QString& mode);
         void openLocalPackage(const QUrl &localfile);
 
+        void copyTextToClipboard(const QString &text);
+
     private Q_SLOTS:
         void reportBug();
         void switchApplicationLanguage();
@@ -78,7 +80,7 @@ class DiscoverObject : public QObject
         void listMimeInternal(const QString& mime);
         void listCategoryInternal(Category* cat);
 
-        void compactModeChanged(CompactMode compactMode);
+        void compactModeChanged(DiscoverObject::CompactMode compactMode);
         void preventedClose();
         void unableToFind(const QString &resid);
         void openErrorPage(const QString &errorMessage);
